==> zio-aws-apigatewayv2_3-5.17.104.8-sources.jar: zio/aws/apigatewayv2/model/GetStagesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetStagesResponse(
    items: Option[Iterable[zio.aws.apigatewayv2.model.Stage]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse = {
    import GetStagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetStagesResponse.wrap(buildAwsValue())
}
object GetStagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetStagesResponse =
      zio.aws.apigatewayv2.model.GetStagesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.apigatewayv2.model.Stage.ReadOnly]]
    def nextToken: Option[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Stage.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ) extends zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly {
    override val items
        : Option[List[zio.aws.apigatewayv2.model.Stage.ReadOnly]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.Stage.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ): zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.20.42.1-sources.jar: zio/aws/apigatewayv2/model/GetStagesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetStagesResponse(
    items: Optional[Iterable[zio.aws.apigatewayv2.model.Stage]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse = {
    import GetStagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetStagesResponse.wrap(buildAwsValue())
}
object GetStagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetStagesResponse =
      zio.aws.apigatewayv2.model.GetStagesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[List[zio.aws.apigatewayv2.model.Stage.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Stage.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ) extends zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.apigatewayv2.model.Stage.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.apigatewayv2.model.Stage.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStagesResponse
  ): zio.aws.apigatewayv2.model.GetStagesResponse.ReadOnly = new Wrapper(impl)
}
